@@ -1,14 +1,14 @@
 # Module for configuration file management
-# Last modified: 2007-01-04T14:46:14-05:00
+# Last modified: 2008-11-17T01:03:59-05:00
 
-### WARNING ###
+# --- WARNING ---
 # config variables that must always load
 
 # automatically set time zone using GNU specific, 'date +%z'
-tzd_mm=`date +%z |cut -c4-5`
-AUTO_TZD=`date +%z |sed 's/..$/\:'$tzd_mm'/'`
-
-### end WARNING ###
+tzd_hhmm=`date +%z`
+tzd_hh=${tzd_hhmm:0:3}; tzd_mm=${tzd_hhmm:3:5}
+AUTO_TZD=${tzd_hh}:${tzd_mm}
+# ---
 
 # loads global config
 load_globals(){
@@ -22,6 +22,10 @@ load_globals(){
 
 # loads global and user configurations
 load_config(){
+# set temp directory
+NB_TEMP_DIR="/tmp"
+# prompt to use when asking something.
+NB_PROMPT=": "
 # set deprecated BASE_DIR for temporary compatibility
 BASE_DIR="$NB_BASE_DIR"
 load_globals
@@ -50,34 +54,37 @@ export BLOG_DIR
 : ${PLUGINS_DIR:=$NB_BASE_DIR/plugins}
 # default location for user plugins
 : ${USR_PLUGINSDIR:=$BLOG_DIR/plugins}
+# default articles suffix
+: ${ARTICLES_SUFFIX:=txt}
 
-### WARNING ###
+# --- WARNING ---
 # changing the following requires manually modifying
-# the "default" and weblog directory structure
+# the weblog directory structure
 
 # load user defined directory to store archives
 ARCHIVES_DIR="$BLOG_ARCHIVES_DIR"
 # default directory to store archives of weblog
 [ -z "$ARCHIVES_DIR" ] && ARCHIVES_DIR=archives
-
 # load user defined directory to store cached data
 CACHE_DIR="$BLOG_CACHE_DIR"
 # default directory to store cached data of weblog
 [ -z "$CACHE_DIR" ] && CACHE_DIR=cache
-
 # load user defined directory to store parts
 PARTS_DIR="$BLOG_PARTS_DIR"
 # default directory to store parts of weblog
 [ -z "$PARTS_DIR" ] && PARTS_DIR=parts
-
-### end WARNING ###
+# default directory to store articles of weblog
+[ -z "$ARTICLES_DIR" ] && ARTICLES_DIR=articles
 
 # letter to prepend to entry's html id tag
 # WARNING: effects permanent links
 # load user defined id tag
 x_id="$BLOG_ENTRYID_TAG"
 : ${x_id:=e}
+# ---
 
+# default verbosity, 0 = silent
+: ${VERBOSE:=1}
 # default to $USER for author
 : ${BLOG_AUTHOR:=$USER}
 # allow user specified author names
@@ -86,6 +93,8 @@ x_id="$BLOG_ENTRYID_TAG"
 [ -z "$NB_BROWSER" ] && [ ! -z "$BROWSER" ] &&
 	NB_BROWSER="$BROWSER"
 : ${NB_BROWSER:=lynx}
+# export NB_BROWSER for the benefit of other components
+export NB_BROWSER
 # smart defaults for date locale
 if [ -n "$LC_ALL" ]; then
 	: ${DATE_LOCALE:=$LC_ALL}
@@ -98,10 +107,19 @@ fi
 : ${DATE_CMD:=date}
 # default data file date format
 : ${DB_DATEFORMAT:="%Y-%m-%dT%H_%M_%S"}
-# default to $EDITOR then vi for editor
+# default to $EDITOR first then vi
 [ -z "$NB_EDITOR" ] && [ ! -z "$EDITOR" ] &&
 	NB_EDITOR="$EDITOR"
 : ${NB_EDITOR:=vi}
+# export NB_EDITOR for the benefit of other components
+export NB_EDITOR
+# cleanup EDITOR/NB_EDITOR & create NB_EDITORNAME for templates
+if [ -z "$NB_EDITORNAME" ]; then
+	NB_EDITORNAME="${NB_EDITOR//*\// }"
+	NB_EDITORNAME="${NB_EDITORNAME// -*/}"
+fi
+# default file creation mask
+[ -z "$NB_UMASK" ] && NB_UMASK=`umask`
 # default to txt for datatype suffix
 : ${NB_DATATYPE:=txt}
 # default to db for database suffix
@@ -109,16 +127,17 @@ fi
 # default to html for page suffix
 : ${NB_FILETYPE:=html}
 
-### WARNING ###
+# --- WARNING ---
 # changing the following requires manually modifying
 # *all* existing entry data files!
 
 # default metadata marker (a.k.a. spacer)
 : ${METADATA_MARKER:=-----}
-# default metadata close tag (e.g. 'END-----')
-: ${METADATA_CLOSETAG:=$METADATA_MARKER}
-
-### end WARNING ###
+# default metadata close var (e.g. 'END-----')
+: ${METADATA_CLOSEVAR:=END-----}
+# depecrated METADATA_CLOSETAG here for transitional purposes only
+: ${METADATA_CLOSETAG:=$METADATA_CLOSEVAR}
+# ---
 
 # default to raw processing for page content
 : ${PAGE_FORMAT:=raw}
@@ -128,8 +147,12 @@ fi
 : ${NB_SYND_FILETYPE:=xml}
 # default to AUTO_TZD for iso dates
 : ${BLOG_TZD:=$AUTO_TZD}
-# default to max filter for query mode
-: ${QUERY_MODE:=max}
+# defaults to all for query mode
+: ${QUERY_MODE:=all}
+# set default query mode for all operations
+: ${NB_QUERY:=$QUERY_MODE}
+# set default query for main page
+: ${MAINPAGE_QUERY:=max}
 # defaults for maximum entries to display on each page
 : ${MAX_ENTRIES:=10}
 : ${MAX_PAGE_ENTRIES:=$MAX_ENTRIES}
@@ -153,7 +176,8 @@ fi
 # default to auto cache management
 : ${BLOG_CACHEMNG:=1}
 # default for maximum entries to save in cache
-: ${MAX_CACHE_ENTRIES:=$MAX_ENTRIES}
+[ -z "$MAX_CACHE_ENTRIES" ] &&
+	let MAX_CACHE_ENTRIES=${MAX_ENTRIES}*2
 # default chronological order for archives
 : ${CHRON_ORDER:=1}
 # determine sort order (-u required)
@@ -165,32 +189,44 @@ fi
 # override configuration's interactive mode
 [ ! -z "$USR_INTERACTIVE" ] &&
 	BLOG_INTERACTIVE="$USR_INTERACTIVE"
+# default for showing permanent links
+: ${SHOW_PERMALINKS:=1}
+# deprecated PERMALINKS here for transitional purposes only
+: ${PERMALINKS:=$SHOW_PERMALINKS}
 # default for showing category links
-: ${CATEGORY_LINKS:=1}
-# default for category feeds - disabled
-: ${CATEGORY_FEEDS:=0}
+: ${SHOW_CATLINKS:=1}
+# depecrated CATEGORY_LINKS here for tansitional purposes only
+: ${CATEGORY_LINKS:=$SHOW_CATLINKS}
+# default for category feeds - leave unset
+: ${CATEGORY_FEEDS:=}
 # default for friendly links
 : ${FRIENDLY_LINKS:=1}
 # default limit for # of link title characters
 : ${MAX_TITLEWIDTH:=150}
+# default for archives configuration
+: ${ENTRY_ARCHIVES:=0}
+: ${MONTH_ARCHIVES:=1}
+: ${DAY_ARCHIVES:=0}
+# default for archives data
+: ${CATARCH_DATATYPE:=TITLE}
+: ${MONTHARCH_DATATYPE:=ALL}
+: ${DAYARCH_DATATYPE:=ALL}
 }
 
 # deconfigure, clear some auto-default variables
-deconfig(){ ARCHIVES_DIR=; CACHE_DIR=; PARTS_DIR=; BLOG_AUTHOR=; PLUGINS_DIR=; \
-	NB_DATATYPE=; NB_DBTYPE=; NB_FILETYPE=; NB_SYND_FILETYPE=; BLOG_TZD=; \
-	QUERY_MODE=; MAX_ENTRIES=; MAX_PAGE_ENTRIES=; MAX_CATPAGE_ENTRIES=; \
-	MAX_MONTHPAGE_ENTRIES=; MAX_MAINPAGE_ENTRIES=; METADATA_MARKER=; \
-	METADATA_CLOSETAG=; PAGE_FORMAT=; ENTRY_FORMAT=; BLOG_CACHEMNG=; \
-	MAX_CACHE_ENTRIES=; SORT_ARGS=; SHOW_INDEXFILE=; CHRON_ORDER=; \
-	USR_PLUGINSDIR=; CATEGORY_LINKS=; CATEGORY_FEEDS=; FRIENDLY_LINKS=; \
-	MAX_TITLEWIDTH=;
-}
-
-# edit $BLOG_CONF
-config_weblog(){
-nb_edit "$BLOG_CONF"
-# check if file's been modified since opened
-[ ! -N "$BLOG_CONF" ] && die "$configweblog_nomod"
-deconfig; load_config
+deconfig(){ ARCHIVES_DIR=; CACHE_DIR=; NB_DATA_DIR=; NB_TEMPLATES_DIR=; NB_TEMP_DIR=; \
+	USR_PLUGINSDIR=; PARTS_DIR=; PLUGINS_DIR=; \
+	NB_DATATYPE=; NB_DBTYPE=; NB_FILETYPE=; NB_INDEXFILE=; NB_SYND_FILETYPE=; NB_PROMPT=; \
+	NB_UMASK=; \
+ 	BLOG_AUTHOR=; BLOG_CACHEMNG=; BLOG_INTERACTIVE=; BLOG_TZD=; \
+	CATEGORY_FEEDS=; CHRON_ORDER=; DATE_CMD=; DATE_LOCALE=; FRIENDLY_LINKS=; \
+	MAINPAGE_QUERY=; MAX_ENTRIES=; MAX_CACHE_ENTRIES=; MAX_CATPAGE_ENTRIES=; \
+	MAX_MAINPAGE_ENTRIES=; MAX_MONTHPAGE_ENTRIES=; MAX_PAGE_ENTRIES=; MAX_TITLEWIDTH=; \
+	METADATA_MARKER=; METADATA_CLOSEVAR=; METADATA_CLOSETAG=; \
+	ENTRY_FORMAT=; PAGE_FORMAT=; \
+	SHOW_INDEXFILE=; SHOW_PERMALINKS=; SHOW_CATLINKS=; SORT_ARGS=; \
+	CATARCH_DATATYPE=; DAYARCH_DATATYPE=; MONTHARCH_DATATYPE=; \
+	ENTRY_ARCHIVES=; DAY_ARCHIVES=; MONTH_ARCHIVES=; \
+	QUERY_MODE=
 }
 
