@@ -1,12 +1,12 @@
 # Nanoblogger Plugin: Weblog Links
-# Last modified: 2007-01-04T03:22:21-05:00
+# Last modified: 2008-01-13T21:36:41-05:00
 
 # <div class="sidetitle">
 # Links
 # </div>
 #
 # <div class="side">
-# $NB_Main_Links
+# $NB_MainLinks
 # </div>
 
 # <div class="sidetitle">
@@ -14,7 +14,7 @@
 # </div>
 #
 # <div class="side">
-# $NB_Category_Links
+# $NB_CategoryLinks
 # </div>
 
 # <div class="sidetitle">
@@ -22,7 +22,7 @@
 # </div>
 #
 # <div class="side">
-# $NB_Month_Links
+# $NB_MonthLinks
 # </div>
 
 # command used to filter order of category links
@@ -66,15 +66,15 @@ NB_MainLinks="$TEMPLATE_DATA"
 
 # create links for categories
 build_catlinks(){
-for cat_link in ${db_categories[*]}; do
-	if [ -f "$NB_DATA_DIR/$cat_link" ]; then
-		#cat_index=`chg_suffix "$cat_link"`
-		#cat_feed=`chg_suffix "$cat_link" "$NB_SYND_FILETYPE"`
-		set_catlink "$cat_link"
+for bcat_link in ${db_categories[*]}; do
+	if [ -f "$NB_DATA_DIR/$bcat_link" ]; then
+		#cat_index=`chg_suffix "$bcat_link"`
+		#cat_feed=`chg_suffix "$bcat_link" "$NB_SYND_FILETYPE"`
+		set_catlink "$bcat_link"
 		cat_index="$category_link"
-		query_db "$db_query" "$cat_link"
+		query_db "$db_query" "$bcat_link"
 		cat_total=${#DB_RESULTS[*]}
-		NB_CategoryTitle=`sed 1q "$NB_DATA_DIR/$cat_link"`
+		NB_CategoryTitle=`nb_print "$NB_DATA_DIR/$bcat_link" 1`
 		cat <<-EOF
 			<!-- $NB_CategoryTitle --><a href="${ARCHIVES_PATH}$cat_index">$NB_CategoryTitle</a> ($cat_total) <br />
 		EOF
@@ -92,7 +92,7 @@ for query_nyear in ${NYEARS[*]}; do
 	query_db "$query_nyear"
 	months_nyear=${#DB_RESULTS[*]}
 	[ "$months_nyear" -gt 0 ] &&
-		month_tally=`expr $month_tally + $months_nyear`
+		let month_tally=${month_tally}+$months_nyear
 done
 
 # get total number of months and tally total entries from MAX_MONTHLINKS
@@ -105,24 +105,25 @@ for query_nmonth in ${NMONTHS[*]}; do
 	query_db "$query_nmonth"
 	entries_nmonth=${#DB_RESULTS[*]}
 	[ "$entries_nmonth" -gt 0 ] &&
-		entry_tally=`expr $entry_tally + $entries_nmonth`
+		let entry_tally=${entry_tally}+$entries_nmonth
 done
 
-build_catlinks |$CATLINKS_FILTERCMD |sed -e 's/<!-- .* -->//' > "$BLOG_DIR/$PARTS_DIR/category_links.$NB_FILETYPE"
-NB_CategoryLinks=$(< "$BLOG_DIR/$PARTS_DIR/category_links.$NB_FILETYPE")
+build_catlinks |$CATLINKS_FILTERCMD |sed -e 's/<!-- .* -->//' > "$BLOG_DIR/$PARTS_DIR/cat_links.$NB_FILETYPE"
+NB_CategoryLinks=$(< "$BLOG_DIR/$PARTS_DIR/cat_links.$NB_FILETYPE")
+[ -z "$NB_CategoryLinks" ] && NB_CategoryLinks="$categories_nolist"
 
 # create links to feeds
 if [ "$CATEGORY_FEEDS" = 1 ] || [ "$ATOM_CATFEEDS" = 1 -a "$RSS2_CATFEEDS" = 1 ]; then
 	# TODO: find a better way to check if atom or rss feeds exist before adding them blindly
 	# TODO: include RSS 1.0 feeds or just forget about them?
-	sed 's@<a href="\([^"]*\)\('$NB_INDEX'\)\{'$SHOW_INDEXFILE'\}">\([^<]*\)</a>.*@\3 (<a href="\1index-rss.xml" class="feed-small">RSS</a>, <a href="\1index-atom.xml" class="feed-small">Atom</a>)<br />@' "$BLOG_DIR/$PARTS_DIR/category_links.$NB_FILETYPE" > "$BLOG_DIR/$PARTS_DIR/category_feeds.$NB_FILETYPE"
-	NB_CategoryFeeds=$(< "$BLOG_DIR/$PARTS_DIR/category_feeds.$NB_FILETYPE")
+	sed 's@<a href="\([^"]*\)\('$NB_INDEX'\)\{'$SHOW_INDEXFILE'\}">\([^<]*\)</a>.*@\3 (<a href="\1index-rss.xml" class="feed-small">RSS</a>, <a href="\1index-atom.xml" class="feed-small">Atom</a>)<br />@' "$BLOG_DIR/$PARTS_DIR/cat_links.$NB_FILETYPE" > "$BLOG_DIR/$PARTS_DIR/cat_feeds.$NB_FILETYPE"
+	NB_CategoryFeeds=$(< "$BLOG_DIR/$PARTS_DIR/cat_feeds.$NB_FILETYPE")
 elif [ "$ATOM_CATFEEDS" = 1 ] && [ "$RSS2_CATFEEDS" != 1 ]; then
-	sed 's@<a href="\([^"]*\)\('$NB_INDEX'\)\{'$SHOW_INDEXFILE'\}">\([^<]*\)</a>.*@\3 (<a href="\1index-atom.xml" class="feed-small">Atom</a>)<br />@' "$BLOG_DIR/$PARTS_DIR/category_links.$NB_FILETYPE" > "$BLOG_DIR/$PARTS_DIR/category_feeds.$NB_FILETYPE"
-	NB_CategoryFeeds=$(< "$BLOG_DIR/$PARTS_DIR/category_feeds.$NB_FILETYPE")
+	sed 's@<a href="\([^"]*\)\('$NB_INDEX'\)\{'$SHOW_INDEXFILE'\}">\([^<]*\)</a>.*@\3 (<a href="\1index-atom.xml" class="feed-small">Atom</a>)<br />@' "$BLOG_DIR/$PARTS_DIR/cat_links.$NB_FILETYPE" > "$BLOG_DIR/$PARTS_DIR/cat_feeds.$NB_FILETYPE"
+	NB_CategoryFeeds=$(< "$BLOG_DIR/$PARTS_DIR/cat_feeds.$NB_FILETYPE")
 elif [ "$RSS2_CATFEEDS" = 1 ] && [ "$ATOM_CATFEEDS" != 1 ]; then
-	sed 's@<a href="\([^"]*\)\('$NB_INDEX'\)\{'$SHOW_INDEXFILE'\}">\([^<]*\)</a>.*@\3 (<a href="\1index-rss.xml" class="feed-small">RSS</a>)<br />@' "$BLOG_DIR/$PARTS_DIR/category_links.$NB_FILETYPE" > "$BLOG_DIR/$PARTS_DIR/category_feeds.$NB_FILETYPE"
-	NB_CategoryFeeds=$(< "$BLOG_DIR/$PARTS_DIR/category_feeds.$NB_FILETYPE")
+	sed 's@<a href="\([^"]*\)\('$NB_INDEX'\)\{'$SHOW_INDEXFILE'\}">\([^<]*\)</a>.*@\3 (<a href="\1index-rss.xml" class="feed-small">RSS</a>)<br />@' "$BLOG_DIR/$PARTS_DIR/cat_links.$NB_FILETYPE" > "$BLOG_DIR/$PARTS_DIR/cat_feeds.$NB_FILETYPE"
+	NB_CategoryFeeds=$(< "$BLOG_DIR/$PARTS_DIR/cat_feeds.$NB_FILETYPE")
 fi
 
 # helper to create links to year archives
@@ -177,17 +178,18 @@ fi
 NB_YearLinks=$(< "$BLOG_DIR/$PARTS_DIR/year_links.$NB_FILETYPE")
 
 # create monthly archive links
-if [ "$ALL_MONTHLINKS" = 1 ]; then
-	query_db all
-else
-	query_db all nocat limit $entry_tally 1
+if [ "$MONTH_ARCHIVES" = 1 ]; then
+	if [ "$ALL_MONTHLINKS" = 1 ]; then
+		query_db all
+	else
+		query_db all nocat limit $entry_tally 1
+	fi
+	loop_archive "${DB_RESULTS[*]}" months make_monthlink |sort $SORT_ARGS > "$BLOG_DIR/$PARTS_DIR/month_links.$NB_FILETYPE"
+	# monthly archives continued
+	if [ $ALL_MONTHLINKS != 1 ] && [ $MAX_MONTHLINKS -lt $total_nmonths ]; then
+		cat >> "$BLOG_DIR/$PARTS_DIR/month_links.$NB_FILETYPE" <<-EOF
+			<a href="${ARCHIVES_PATH}$NB_INDEX">$NB_NextPage</a>
+		EOF
+	fi
+	NB_MonthLinks=$(< "$BLOG_DIR/$PARTS_DIR/month_links.$NB_FILETYPE")
 fi
-loop_archive "${DB_RESULTS[*]}" months make_monthlink |sort $SORT_ARGS > "$BLOG_DIR/$PARTS_DIR/month_links.$NB_FILETYPE"
-# monthly archives continued
-if [ $ALL_MONTHLINKS != 1 ] && [ $MAX_MONTHLINKS -lt $total_nmonths ]; then
-	cat >> "$BLOG_DIR/$PARTS_DIR/month_links.$NB_FILETYPE" <<-EOF
-		<a href="${ARCHIVES_PATH}$NB_INDEX">$NB_NextPage</a>
-	EOF
-fi
-NB_MonthLinks=$(< "$BLOG_DIR/$PARTS_DIR/month_links.$NB_FILETYPE")
-
